@@ -40,11 +40,9 @@ cast_shadow <- function(data, ...){
 
   }
 
-    quo_vars <- rlang::quos(...)
+    shadow_vars <- dplyr::select(data, ...) %>% as_shadow()
 
-    shadow_vars <- dplyr::select(data, !!!quo_vars) %>% as_shadow()
-
-    my_data <- dplyr::select(data, !!!quo_vars)
+    my_data <- dplyr::select(data, ...)
 
     tibble::as_tibble(dplyr::bind_cols(my_data, shadow_vars))
 
@@ -74,9 +72,7 @@ cast_shadow <- function(data, ...){
 #'
 cast_shadow_shift <- function(data, ...){
 
-  quo_vars <- rlang::quos(...)
-
-  shadow_vars <- dplyr::select(data, !!!quo_vars) %>% cast_shadow(...)
+  shadow_vars <- dplyr::select(data, ...) %>% cast_shadow(...)
 
   # shift those values selected
   add_shadow_shift(shadow_vars, ...)
@@ -118,9 +114,7 @@ cast_shadow_shift_label <- function(data, ...){
     stop("please include variables to be selected after the data")
   }
 
-  quo_vars <- rlang::quos(...)
-
-  shadow_vars <- dplyr::select(data, !!!quo_vars) %>% cast_shadow(...)
+  shadow_vars <- dplyr::select(data, ...) %>% cast_shadow(...)
 
   # shift those values selected
   add_shadow_shift(shadow_vars, ...) %>% add_label_missings()
