@@ -165,9 +165,7 @@ bind_shadow <- function(data, only_miss = FALSE, ...){
 #' @return object with class "shadow", inheriting from it's original class
 #' @export
 new_shadow <- function(x){
-    # structure(x,
-    #           class = c("shadow", class(x)))
-    tibble::new_tibble(x, subclass = "shadow")
+  tibble::new_tibble(x, subclass = "shadow", nrow = nrow(x))
 }
 
 
@@ -372,7 +370,7 @@ shadow_long <- function(shadow_data,
   }
 
   if (!missing(...)) {
-    vars <- bare_to_chr(...)
+    vars <- purrr::map(ensyms(...), as_string)
     gathered_df <- gathered_df %>%
       dplyr::filter(variable %in% vars)
   }
